#!/usr/bin/env python
if __name__ != '__main__': raise Exception("Do not import me!")

import chainer
import logging

from chainer.training.updaters import StandardUpdater

from cvfinetune.finetuner import DefaultFinetuner

from utils import parser
from core import classifier, dataset, trainer

def main(args):
	if args.debug:
		chainer.set_debug(args.debug)
		logging.warning("DEBUG MODE ENABLED!")


	tuner = DefaultFinetuner(
		args,
		classifier_cls=classifier.FVEClassifier,
		classifier_kwargs=dict(
			n_comps=args.n_components,
			fv_insize=args.fv_insize,
			alpha=args.alpha,
		),

		model_kwargs=dict(
			pooling=args.pooling,
		),

		dataset_cls=dataset.PartsDataset,

		updater_cls=StandardUpdater,
		updater_kwargs={},
	)


	tuner.run(trainer_cls=trainer.PartsTrainer, opts=args)


main(parser.parse_args())
